@@ -1,4 +1,4 @@
-/* $Id: VBoxNetFltInternal.h 83687 2013-02-08 12:50:49Z fmehnert $ */
+/* $Id: VBoxNetFltInternal.h 86926 2013-07-03 11:07:54Z aleksey $ */
 /** @file
  * VBoxNetFlt - Network Filter Driver (Host), Internal Header.
  */
@@ -159,6 +159,8 @@ typedef struct VBOXNETFLTINS
              * @{ */
             /** Pointer to the device. */
             struct net_device * volatile pDev;
+            /** MTU of host's interface. */
+            uint32_t cbMtu;
             /** Whether we've successfully put the interface into to promiscuous mode.
              * This is for dealing with the ENETDOWN case. */
             bool volatile fPromiscuousSet;
