@@ -1,4 +1,4 @@
-/* $Id: the-linux-kernel.h 84023 2013-02-28 13:55:18Z fmehnert $ */
+/* $Id: the-linux-kernel.h 91596 2014-01-14 10:17:49Z fmehnert $ */
 /** @file
  * IPRT - Include all necessary headers for the Linux kernel.
  */
@@ -145,6 +145,10 @@
 # define DEFINE_WAIT(name) DECLARE_WAITQUEUE(name, current)
 #endif
 
+#ifndef __GFP_NOWARN
+# define __GFP_NOWARN 0
+#endif
+
 /*
  * 2.4 / early 2.6 compatibility wrappers
  */
